set more 1
cd "[PATH]\tables\"

*********************************
**** EXPERIMENT 1 ***************************
*********************************
use "..\study_1.dta", clear
drop if country!="United States"
drop if state=="Palau"

** DEMOGRAPHICS
egen pid=rmean(pid_dstr pid_rstr pid_lean)
drop if round(pid)!=pid
replace pid=pid/3
label var pid "Respondent Party ID (-1=S Dem; 1=S Rep)"
gen pure_indep=pid==0
label var pure_indep "Pure independent (1=yes)"


gen age=2011-yob
label var age "Age (in years)"
drop if age<18

label var educ "Education (1=No HS; 6=post-grad)"
label var income "Income (1=<$10k; 14=$150k+; 15=refused)"
gen incomemis=(income==15)
label var incomemis "Income Refused (1=yes)"

foreach i in white black hispanic asian nativeam mixed other{
 replace r_`i'=0 if r_`i'==.
 replace r_`i'=1 if r_`i'!=0
 label var r_`i' "`i' = 1"
}
replace r_other=r_asian+r_nativeam+r_mixed+r_other
replace r_other=1 if r_other>1
replace r_white=0 if (r_black==1)| (r_hispanic==1)|(r_other==1)
replace r_black=0 if (r_hispanic==1)|(r_other==1)
replace r_hispanic=0 if (r_other==1)
replace r_other=1 if (r_white!=1)&(r_black!=1)&(r_hispanic!=1)

drop r_asian r_nativeam r_mixed 
label var r_white "White (1=yes)"
label var r_black "Black (1=yes)"
label var r_hispanic  "Hispanic (1=yes)"
label var r_other "Other race/skipped (1=yes)"
label var female "Female (1=yes)"

label var polinterest "Interest in politics (1=not at all; 3=very interested)"

recode ideol (-2=2) (-1=1) (0 8=0) (1=-1) (2=-2) (*=.), gen(ideology)
label var ideology "Ideology (-2=v. liberal; 2=v. conservative)"

*** TREATMENTS
gen issue_farm=1 if treat_issue=="farm subsidies"
replace issue_farm=0 if treat_issue=="nuclear power plants"
label var issue_farm "Policy Area (1=Farm Subsidies)"
label var treat_inst "Institutional Context Treatment"

*** policy agreement measure
gen rep_vote_for=1 if treat_position_1=="for"
replace rep_vote_for=0 if treat_position_1=="against"

gen policy_increase=1 if treat_direction_1=="increase"
replace policy_increase=-1 if treat_direction_1=="decrease"
label var policy_increase "Policy Direction (-1=decrease; 1=increase)"

gen policyraw=policy_pref
label var policyraw "Spending preference (1=Decrease a lot; 4=Increase a lot)"
replace policy_pref=(policy_pref-1)/3*2-1
label var policy_pref "Policy Preference (-1=Decrease a lot; 1=Increase a lot)"

gen policy_supp=policy_pref*policy_increase
label var policy_supp "Respondent Policy Pref. (-1=S Oppose 1=S Support)"

recode rep_vote_for (1=1) (0=-1)
label var rep_vote_for "Representative Position Treatment (-1=Against; 1=For)"

gen policy_agree=policy_supp*rep_vote_for 
replace policy_agree=policy_agree>0 
replace policy_agree=. if policy_supp==.
label var policy_agree "Policy Agreement (1=yes)"

*** party agreement measure
gen party_rep=treat_party=="Republican"
gen party_dem=treat_party=="Democratic"
gen party_none=treat_party==""

label var party_rep "Party Treatment: Republican"
label var party_dem "Party Treatment: Democrat"
label var party_none "Party Treatment: None"

gen party_treat=party_rep-party_dem
gen party_agree=pid*party_treat
gen party_opposing=party_agree<0
gen party_preferred=party_agree>0
label var party_preferred "Representative from Preferred Party (1=yes)"
label var party_opposing "Representative from Opposing Party (1=yes)"
gen policy_agreeXparty_preferred=policy_agree*party_preferred
gen policy_agreeXparty_opposing=policy_agree*party_opposing
label var policy_agreeXparty_preferred "Policy Agreement x Preferred Party"
label var policy_agreeXparty_opposing "Policy Agreement x Opposing Party"


* Issue interactions
foreach i in policy_agree party_preferred party_opposing {
gen issueX`i'=issue_farm*`i'
local label : variable label `i'
label var issueX`i' "Policy Area x `label'"
}


**** MOTIVE VARIABLES
label var motive_help_inneed "Help people in need"
label var motive_goodpolicy "Make good policy"
label var motive_amerpub "Serve the American public"
label var motive_district "Serve the people in his district"
label var motive_influence "Increase political influence"
label var motive_specint "Special interest influence"
label var motive_reelect "Reelection goals"
label var motive_pander "Pander to voters"
label var motive_pressure "Party pressure"
label var motive_values "Personal values"
label var motive_ownprefs "His own policy preferences"
label var motive_ideology "Ideological reasons"
label var motive_ownfeelings "Own feelings about the bill"

* RESTRICT SAMPLE
reg motive_* policy_supp policy_agree pid issue_farm age educ r_* female polinterest ideology income incomemis vote rate
keep if e(sample)

* CHECK BALANCE
gen condition=issue_farm+10*party_treat+100*rep_vote_for+1000*policy_increase
gen condition_collapsed=10*party_treat+100*rep_vote_for+1000*policy_increase
mlogit condition pid age educ r_* female polinterest ideology income incomemis
mlogit condition_collapsed pid age educ r_* female polinterest ideology income incomemis

*** EVALUATION OF REPRESENTATIVE
corr vote rate
egen eval_rep=rmean(vote rate)
label var eval_rep "Evaluation of Representative Index (0-10)"
label var vote "Make you More Likely to Vote For Rep? (0-10)"
label var rate "Rating of Job as Representative (0-10)"
egen eval_rep_std=std(eval_rep)
label var eval_rep_std "Evaluation of Representative Index (M=0; SD=1)"


* TABLE A1: Summary stats
outsum age female r_* educ income incomemis polinterest ideology policyraw pid eval_rep using "sumstats", replace bracket

* ITEM MEANS
ci motive_*, sep(0)

*** Motive Indices
***TABLE A3: PCFs
factor motive_influence motive_specint motive_reelect motive_pander motive_pressure motive_help_inneed motive_goodpolicy motive_amerpub motive_district motive_values motive_ownprefs motive_ideology motive_ownfeelings,pcf
rotate
predict mot_pol mot_rep mot_per
label var mot_pol "Political Motives"
label var mot_rep "Representation Motives"
label var mot_per "Policy Motives"

foreach i in mot_pol mot_rep mot_per {
gen `i'Xinst=`i'*treat_instcontext
local label : variable label `i'
label var `i'Xinst "`label' x Institutional Context Treatment"
}


***** REGRESSIONS
foreach i in mot_pol mot_rep mot_per {
*TABLE 1
reg `i' policy_agree party_preferred party_opposing issue_farm pure_indep, r
lincom party_preferred-party_opposing 
local ptyfx=r(estimate)
test party_preferred==party_opposing 
if "`i'"=="mot_pol"{
outreg using "regressions.out", se bracket replace rdec(3) adec(3) addstat("Estimated Effect of Party Agreement",`ptyfx',"Test of equality of party agreement treatments (p-value)",r(p))
}
else{
outreg using "regressions.out", se bracket append rdec(3) adec(3) addstat("Estimated Effect of Party Agreement",`ptyfx',"Test of equality of party agreement treatments (p-value)",r(p))
}
reg `i' policy_agree party_preferred party_opposing policy_agreeXparty_preferred policy_agreeXparty_opposing issue_farm pure_indep, r
test policy_agreeXparty_preferred==policy_agreeXparty_opposing 
outreg using "regressions.out", se bracket append rdec(3) adec(3) addstat("Joint sig. of Party x Policy Agreement Interactions (p-value)",r(p))


*POLICY AREA INTERACTIONS: TABLE A2
reg `i' policy_agree party_preferred party_opposing pure_indep issueXpolicy_agree issueXparty_preferred issueXparty_opposing issue_farm, r
test issueXpolicy_agree 
local policy=r(p)
test issueXparty_preferred==issueXparty_opposing
local ptyinteract=r(p)
if "`i'"=="mot_pol"{
outreg using "issueinteractions.out", se bracket replace rdec(3) adec(3) addstat("Policy Agreement Interaction (p-value)",`policy', "Test of Equality of Party Agreement Interactions (p-value)",`ptyinteract')
}
else{
outreg using "issueinteractions.out", se bracket append rdec(3) adec(3) addstat("Policy Agreement Interaction (p-value)",`policy', "Test of Equality of Party Agreement Interactions (p-value)",`ptyinteract')
}
}

*TABLE A4: REGRESSIONs BY ITEM
foreach i in motive_influence motive_specint motive_reelect motive_pander motive_pressure motive_help_inneed motive_goodpolicy motive_amerpub motive_district motive_values motive_ownprefs motive_ideology motive_ownfeelings{
reg `i' policy_agree party_preferred party_opposing issue_farm pure_indep, r
lincom party_preferred-party_opposing 
local ptyfx=r(estimate)
test party_preferred==party_opposing 
local pty_p=r(p)
if "`i'"=="motive_influence"{
outreg using "item_regressions.out", se bracket replace rdec(3) adec(3) addstat("Estimated Effect of Party Agreement",`ptyfx',"Sig. of Party Agreement Effect (p-value)",`pty_p')
}
else{
outreg using "item_regressions.out", se bracket append rdec(3) adec(3) addstat("Estimated Effect of Party Agreement",`ptyfx',"Sig. of Party Agreement Effect (p-value)",`pty_p')
}
}

***** TABLE 3: CORRELATIONS WITH EVALUATIONS OF REP
reg eval_rep_std mot_pol mot_rep mot_per, r
outreg using "evaluations.out", se bracket replace rdec(3) 
reg eval_rep_std mot_pol mot_rep mot_per policy_agree party_preferred party_opposing issue_farm pure_indep pid age educ r_black r_hisp r_other female polinterest ideology income incomemis , r
outreg using "evaluations.out", se bracket append rdec(3) 

***** TABLE A6: Institutional Context Interactions: First Experiment
reg eval_rep_std mot_pol mot_rep mot_per treat_inst mot*inst issue_farm, r
test mot_polXinst mot_repXinst mot_perXinst 
outreg using "inst_evaluations.out", se bracket replace rdec(3) adec(3) addstat("Test of joint significance of interactions (p-value)",r(p))

***** TABLE A7: CORRELATIONS WITH EVALUATIONS OF REP
pwcorr eval_rep motive_influence motive_specint motive_reelect motive_pander motive_pressure motive_help_inneed motive_goodpolicy motive_amerpub motive_district motive_values motive_ownprefs motive_ideology motive_ownfeelings, sig

***** TABLE A8: CORRELATIONS W/EVALUATIONS OF REP BY POLICY AGREEMENT
reg eval_rep_std mot_pol mot_rep mot_per if policy_agree==0, r
outreg using "evaluations.out", se bracket replace rdec(3) 
reg eval_rep_std mot_pol mot_rep mot_per if policy_agree==1, r
outreg using "evaluations.out", se bracket append rdec(3) 

*************************************************
**** EXPERIMENT 2 ***************************
*************************************************
use "..\study_2.dta", clear
drop if country!="United States"
rename whichstatedoyoulivein state

** DEMOGRAPHICS
*Party ID
rename generallyspeakingdoyouusuallythi pid_stem
rename wouldyoucallyourselfastrongdemoc pid_dstr
rename wouldyoucallyourselfastrongrepub pid_rstr
rename doyouthinkofyourselfasclosertoth pid_lean
egen pid=rmean(pid_dstr pid_rstr pid_lean)
drop if round(pid)!=pid
replace pid=pid/3
label var pid "Respondent Party ID (-1=S Dem; 1=S Rep)"
gen pure_indep=pid==0
label var pure_indep "Pure independent (1=yes)"


rename whatistheyearofyourbirth yob
gen age=2014-yob
label var age "Age (in years)"

rename whatisthehighestlevelofeducation educ
label var educ "Education (1=No HS; 6=post-grad)"
rename whatwasyourtotalfamilyincomein20 income
label var income "Income (1=<$10k; 14=$150k+; 15=refused)"
gen incomemis=(income==15)
label var incomemis "Income Refused (1=yes)"

tab whatracialorethnicgrouporgroupsb,gen(r_)
rename r_1 r_white
rename r_2 r_black
rename r_3 r_hispanic
gen r_other=r_4+r_5+r_6+r_7
drop r_4-r_7
label var r_other "Other race / Skipped (1=yes)"
label var r_white "White (1=yes)"
label var r_black "Black (1=yes)"
label var r_hispanic "Hispanic (1=yes)"

gen female=.
replace female=1 if whatisyourgender=="Female"
replace female=0 if whatisyourgender=="Male"
label var female "Female (1=yes)"

recode howinterestedareyouinpoliticsand (1=3) (2=2) (3=1) (*=.), gen(polinterest)
label var polinterest "Interest in politics (1=not at all; 3=very interested)"

gen ideology=.
replace ideology=-3 if wehearalotoftalkthesedaysaboutli=="Extremely liberal"
replace ideology=-2 if wehearalotoftalkthesedaysaboutli=="Liberal"
replace ideology=-1 if wehearalotoftalkthesedaysaboutli=="Slightly liberal"
replace ideology=0 if wehearalotoftalkthesedaysaboutli=="Moderate, middle of the road"
replace ideology=1 if wehearalotoftalkthesedaysaboutli=="Slightly conservative"
replace ideology=2 if wehearalotoftalkthesedaysaboutli=="Conservative"
replace ideology=3 if wehearalotoftalkthesedaysaboutli=="Extremely conservative"
label var ideology "Ideology (-3=v. liberal; 3=v. conservative)"

**** MOTIVE VARIABLES
rename governmentfundingforsubsidiesand motive_ownfeelings
rename v55 motive_values
rename v56 motive_ownprefs
rename v57 motive_ideology
rename v58 motive_district
rename v59 motive_amerpub
rename v60 motive_help_inneed
rename v61 motive_goodpolicy
rename v62 motive_specint
rename v63 motive_reelect
rename v64 motive_pressure
rename v65 motive_influence 
rename v66 motive_pander

label var motive_help_inneed "Help people in need"
label var motive_goodpolicy "Make good policy"
label var motive_amerpub "Serve the American public"
label var motive_district "Serve the people in his district"
label var motive_influence "Increase political influence"
label var motive_specint "Special interest influence"
label var motive_reelect "Reelection goals"
label var motive_pander "Pander to voters"
label var motive_pressure "Party pressure"
label var motive_values "Personal values"
label var motive_ownprefs "His own policy preferences"
label var motive_ideology "Ideological reasons"
label var motive_ownfeelings "Own feelings about the bill"

rename hisownfeelingsaboutthebilltherea norm_ownfeelings
rename hispersonalvaluesthereareavariet norm_values
rename desiretoservethepeopleinhisdistr norm_district
rename desiretoservetheamericanpublicth norm_amerpub
rename reelectiongoalsthereareavarietyo norm_reelect
rename desiretoincreasehispoliticalinfl norm_influence

**Evaluations of representative
rename ifyoulivedinthisrepresentativesd vote
rename basedonwhatyoujustreadhowwouldyo rate

***TREATMENTS***
*** policy agreement measure

gen rep_vote_for=1 if motives_position2=="for"
replace rep_vote_for=-1 if motives_position2=="against"
label var rep_vote_for "Representative Position Treatment (-1=Against; 1=For)"

gen policy_increase=1 if motives_direction1=="increase"
replace policy_increase=-1 if motives_direction1=="decrease"
label var policy_increase "Policy Direction (-1=decrease; 1=increase)"

gen rep_increase=0
replace rep_increase=1 if (policy_increase==1 & rep_vote_for==1) | (policy_increase==-1 & rep_vote_for==-1)

gen policyraw=subsidiesandotherfinancialassist
label var policyraw "Spending preference (1=Decrease a lot; 4=Increase a lot)"
gen policy_pref=(policyraw-1)/3*2-1
label var policy_pref "Policy Preference (-1=Decrease a lot; 1=Increase a lot)"
gen policy_supp=policy_pref*policy_increase
label var policy_supp "Respondent Policy Pref. (-1=S Oppose 1=S Support)"

gen policy_agree=policy_supp*rep_vote_for 
replace policy_agree=policy_agree>0 
replace policy_agree=. if policy_supp==.
label var policy_agree "Policy Agreement (1=yes)"

*** party agreement measure
gen party_rep=motives_party=="Republican"
gen party_dem=motives_party=="Democratic"
gen party_none=motives_party==""

label var party_rep "Party Treatment: Republican"
label var party_dem "Party Treatment: Democrat"
label var party_none "Party Treatment: None"

gen party_treat=party_rep-party_dem
gen party_agree=pid*party_treat
gen party_opposing=party_agree<0
gen party_preferred=party_agree>0
label var party_preferred "Representative from Preferred Party (1=yes)"
label var party_opposing "Representative from Opposing Party (1=yes)"
gen policy_agreeXparty_preferred=policy_agree*party_preferred
gen policy_agreeXparty_opposing=policy_agree*party_opposing
label var policy_agreeXparty_preferred "Policy Agreement x Preferred Party"
label var policy_agreeXparty_opposing "Policy Agreement x Opposing Party"

tab motives_profession, gen(prof_)
tab motives_district, gen(dist_)
drop prof_1 dist_2
rename prof_2 lawyer
rename dist_1 rural
label var lawyer "Lawyer (1=yes)"
gen sidewdist=0
replace sidewdist=1 if (rep_increase==1 & rural==1) | (rep_increase==0 & rural==0)

* RESTRICT SAMPLE
reg motive_* norm_* policy_agree pid age educ r_* female polinterest ideology income incomemis vote rate 
keep if e(sample)

* CHECK BALANCE
gen condition=lawyer+10*party_treat+100*rep_vote_for+1000*policy_increase+10000*rural
mlogit condition pid age educ r_* female polinterest ideology income incomemis


*** EVALUATION OF REPRESENTATIVE
corr vote rate
egen eval_rep=rmean(vote rate)
label var eval_rep "Evaluation of Representative Index (0-10)"
label var vote "Make you More Likely to Vote For Rep? (0-10)"
label var rate "Rating of Job as Representative (0-10)"
egen eval_rep_std=std(eval_rep)
label var eval_rep_std "Evaluation of Representative Index (M=0; SD=1)"


* Summary stats
outsum age female r_* educ income incomemis polinterest ideology policyraw pid eval_rep using "sumstats", append bracket

* ITEM MEANS
ci motive_*, sep(0)

*** Motive Indices
*PCFs
factor motive_influence motive_specint motive_reelect motive_pander motive_pressure motive_help_inneed motive_goodpolicy motive_amerpub motive_district motive_values motive_ownprefs motive_ideology motive_ownfeelings,pcf
rotate
predict mot_rep mot_pol mot_per
label var mot_pol "Political Motives"
label var mot_rep "Representation Motives"
label var mot_per "Policy Motives"


********
***** REGRESSIONS
foreach i in mot_pol mot_rep mot_per {
*TABLE 2
reg `i' policy_agree party_preferred party_opposing sidewdist lawyer pure_indep, r
lincom party_preferred-party_opposing 
local ptyfx=r(estimate)
test party_preferred==party_opposing 
if "`i'"=="mot_pol"{
outreg using "regressions_2.out", se bracket replace rdec(3) adec(3) addstat("Estimated Effect of Party Agreement",`ptyfx',"Test of equality of party agreement treatments (p-value)",r(p))
}
else{
outreg using "regressions_2.out", se bracket append rdec(3) adec(3) addstat("Estimated Effect of Party Agreement",`ptyfx',"Test of equality of party agreement treatments (p-value)",r(p))
}
reg `i' policy_agree party_preferred party_opposing policy_agreeXparty_preferred policy_agreeXparty_opposing sidewdist lawyer pure_indep, r
test policy_agreeXparty_preferred==policy_agreeXparty_opposing 
outreg using "regressions_2.out", se bracket append rdec(3) adec(3) addstat("Joint sig. of Party x Policy Agreement Interactions (p-value)",r(p))
}
*TABLE A5: REGRESSIONs BY ITEM
foreach i in motive_influence motive_specint motive_reelect motive_pander motive_pressure motive_help_inneed motive_goodpolicy motive_amerpub motive_district motive_values motive_ownprefs motive_ideology motive_ownfeelings{
reg `i' policy_agree party_preferred party_opposing sidewdist lawyer pure_indep, r
lincom party_preferred-party_opposing 
local ptyfx=r(estimate)
test party_preferred==party_opposing 
local pty_p=r(p)/2
if "`i'"=="motive_influence"{
outreg using "item_regressions_2.out", se bracket replace rdec(3) adec(3) addstat("Estimated Effect of Party Agreement",`ptyfx',"Test of Equality of Party Agreement Treatments (p-value)",`pty_p')
}
else{
outreg using "item_regressions_2.out", se bracket append rdec(3) adec(3) addstat("Estimated Effect of Party Agreement",`ptyfx',"Test of Equality of Party Agreement Treatments (p-value)",`pty_p')
}
}

***** TABLE 3: CORRELATIONS WITH EVALUATIONS OF REP
reg eval_rep_std mot_pol mot_rep mot_per, r
outreg using "evaluations.out", se bracket append rdec(3) 
reg eval_rep_std mot_pol mot_rep mot_per policy_agree party_preferred party_opposing sidewdist lawyer pure_indep pid age educ r_black r_hisp r_other female polinterest ideology income incomemis, r
outreg using "evaluations.out", se bracket append rdec(3) 

***** TABLE A7: BIVARIATE CORRELATIONS WITH EVALUATIONS OF REP
pwcorr eval_rep motive_influence motive_specint motive_reelect motive_pander motive_pressure motive_help_inneed motive_goodpolicy motive_amerpub motive_district motive_values motive_ownprefs motive_ideology motive_ownfeelings, sig

***** TABLE A8: CORRELATIONS W/EVALUATIONS OF REP BY POLICY AGREEMENT
reg eval_rep_std mot_pol mot_rep mot_per if policy_agree==0, r
outreg using "evaluations.out", se bracket append rdec(3) 
reg eval_rep_std mot_pol mot_rep mot_per if policy_agree==1, r
outreg using "evaluations.out", se bracket append rdec(3) 
